============
Installation
============

.. contents::
   :depth: 3

Development version
===================

Clone from GitHub::
    
    git clone git://github.com/dvdmgl/django-pg-fts.git django-pg-fts

You should run the tests::

    python runtests.py

Or running tox for py27, py33, py34 for django 1.7 and master branch::
    
    tox

Install using pip from source::

    pip install git+https://github.com/dvdmgl/django-pg-fts

Or using setup.py::

    python setup.py
